@@ -130,7 +130,7 @@
 *     ..
       DSDOT = SB
       IF (N.LE.0) THEN
-         SDSDOT = DSDOT
+         SDSDOT = REAL(DSDOT)
          RETURN
       END IF
       IF (INCX.EQ.INCY .AND. INCX.GT.0) THEN
@@ -155,7 +155,7 @@
             KY = KY + INCY
          END DO
       END IF
-      SDSDOT = DSDOT
+      SDSDOT = REAL(DSDOT)
       RETURN
 *
 *     End of SDSDOT
