@@ -9,15 +9,17 @@
  */
 #include "cblas.h"
 #include "cblas_f77.h"
-CBLAS_INDEX cblas_icamax( const int N, const void *X, const int incX)
+CBLAS_INDEX cblas_icamax( const CBLAS_INT N, const void *X, const CBLAS_INT incX)
 {
-   CBLAS_INDEX iamax;
 #ifdef F77_INT
-   F77_INT F77_N=N, F77_incX=incX;
+   F77_INT F77_N=N, F77_incX=incX, F77_iamax;
 #else
    #define F77_N N
    #define F77_incX incX
+   CBLAS_INT F77_iamax;
 #endif
-   F77_icamax_sub( &F77_N, X, &F77_incX, &iamax);
-   return iamax ? iamax-1 : 0;
+   F77_icamax_sub( &F77_N, X, &F77_incX, &F77_iamax );
+   return ( F77_iamax > 0 )
+      ? (CBLAS_INDEX)( F77_iamax-1 )
+      : (CBLAS_INDEX) 0;
 }
