@@ -9,9 +9,9 @@
 
 #include "cblas.h"
 #include "cblas_f77.h"
-void cblas_sger(const CBLAS_LAYOUT layout, const CBLAS_INDEX M, const CBLAS_INDEX N,
-                const float  alpha, const float  *X, const CBLAS_INDEX incX,
-                const float  *Y, const CBLAS_INDEX incY, float  *A, const CBLAS_INDEX lda)
+void cblas_sger(const CBLAS_LAYOUT layout, const CBLAS_INT M, const CBLAS_INT N,
+                const float  alpha, const float  *X, const CBLAS_INT incX,
+                const float  *Y, const CBLAS_INT incY, float  *A, const CBLAS_INT lda)
 {
 #ifdef F77_INT
    F77_INT F77_M=M, F77_N=N, F77_lda=lda, F77_incX=incX, F77_incY=incY;
