@@ -8,8 +8,8 @@
  */
 #include "cblas.h"
 #include "cblas_f77.h"
-void cblas_srot( const int N, float *X, const int incX, float *Y,
-                      const int incY, const float  c, const float  s)
+void cblas_srot( const CBLAS_INT N, float *X, const CBLAS_INT incX, float *Y,
+                      const CBLAS_INT incY, const float  c, const float  s)
 {
 #ifdef F77_INT
    F77_INT F77_N=N, F77_incX=incX, F77_incY=incY;
