@@ -9,12 +9,12 @@
  */
 #include "cblas.h"
 #include "cblas_f77.h"
-void cblas_zdotc_sub( const int N, const void *X, const int incX,
-                      const void *Y, const int incY, void *dotc)
+void cblas_zdotc_sub( const CBLAS_INT N, const void *X, const CBLAS_INT incX,
+                      const void *Y, const CBLAS_INT incY, void *dotc)
 {
 #ifdef F77_INT
    F77_INT F77_N=N, F77_incX=incX, F77_incY=incY;
-#else 
+#else
    #define F77_N N
    #define F77_incX incX
    #define F77_incY incY
