@@ -212,8 +212,6 @@
 *> \author Univ. of Colorado Denver
 *> \author NAG Ltd.
 *
-*> \date January 2015
-*
 *> \ingroup complexOTHERcomputational
 *
 *> \par Further Details:
@@ -221,7 +219,7 @@
 *>
 *> \verbatim
 *>
-*>  This routine reduces A to Hessenberg form and maintains B in
+*>  This routine reduces A to Hessenberg form and maintains B in triangular form
 *>  using a blocked variant of Moler and Stewart's original algorithm,
 *>  as described by Kagstrom, Kressner, Quintana-Orti, and Quintana-Orti
 *>  (BIT 2008).
@@ -231,10 +229,9 @@
       SUBROUTINE CGGHD3( COMPQ, COMPZ, N, ILO, IHI, A, LDA, B, LDB, Q,
      $                   LDQ, Z, LDZ, WORK, LWORK, INFO )
 *
-*  -- LAPACK computational routine (version 3.6.0) --
+*  -- LAPACK computational routine --
 *  -- LAPACK is a software package provided by Univ. of Tennessee,    --
 *  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
-*     January 2015
 *
 *
       IMPLICIT NONE
@@ -271,7 +268,8 @@
       EXTERNAL           ILAENV, LSAME
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           CGGHRD, CLARTG, CLASET, CUNM22, CROT, XERBLA
+      EXTERNAL           CGGHRD, CLARTG, CLASET, CUNM22, CROT, CGEMM,
+     $                   CGEMV, CTRMV, CLACPY, XERBLA
 *     ..
 *     .. Intrinsic Functions ..
       INTRINSIC          REAL, CMPLX, CONJG, MAX
@@ -282,7 +280,7 @@
 *
       INFO = 0
       NB = ILAENV( 1, 'CGGHD3', ' ', N, ILO, IHI, -1 )
-      LWKOPT = 6*N*NB
+      LWKOPT = MAX( 6*N*NB, 1 )
       WORK( 1 ) = CMPLX( LWKOPT )
       INITQ = LSAME( COMPQ, 'I' )
       WANTQ = INITQ .OR. LSAME( COMPQ, 'V' )
@@ -513,7 +511,7 @@
 *
                IF( JJ.GT.0 ) THEN
                   DO I = JJ, 1, -1
-                     C = DBLE( A( J+1+I, J ) )
+                     C = REAL( A( J+1+I, J ) )
                      CALL CROT( IHI-TOP, A( TOP+1, J+I+1 ), 1,
      $                          A( TOP+1, J+I ), 1, C,
      $                          -CONJG( B( J+1+I, J ) ) )
