@@ -258,8 +258,6 @@
 *> \author Univ. of Colorado Denver
 *> \author NAG Ltd.
 *
-*> \date June 2016
-*
 *> \ingroup complex16OTHEReigen
 *
 *  =====================================================================
@@ -267,10 +265,9 @@
      $                   VU, IL, IU, ABSTOL, M, W, Z, LDZ, WORK, RWORK,
      $                   IWORK, IFAIL, INFO )
 *
-*  -- LAPACK driver routine (version 3.7.0) --
+*  -- LAPACK driver routine --
 *  -- LAPACK is a software package provided by Univ. of Tennessee,    --
 *  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
-*     June 2016
 *
 *     .. Scalar Arguments ..
       CHARACTER          JOBZ, RANGE, UPLO
@@ -382,7 +379,7 @@
      $         M = 0
          END IF
          IF( M.EQ.1 ) THEN
-            W( 1 ) = CTMP1
+            W( 1 ) = DBLE( CTMP1 )
             IF( WANTZ )
      $         Z( 1, 1 ) = CONE
          END IF
